pub struct StorageHandle {
pub store: Arc<dyn CredentialStore>,
}Expand description
Keeps storage callbacks in the native library that owns their converters.
Fields
store: Arc<dyn CredentialStore>Trait Implementations
Sourceimpl<UT> LiftRef<UT> for StorageHandle
impl<UT> LiftRef<UT> for StorageHandle
type LiftType = Arc<StorageHandle>
Sourceimpl<UT> LowerError<UT> for StorageHandle
impl<UT> LowerError<UT> for StorageHandle
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for StorageHandle
impl<UT> LowerReturn<UT> for StorageHandle
Sourcetype ReturnType = <Arc<StorageHandle> as LowerReturn<UniFfiTag>>::ReturnType
type ReturnType = <Arc<StorageHandle> as LowerReturn<UniFfiTag>>::ReturnType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(obj: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(obj: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl<UT> TypeId<UT> for StorageHandle
impl<UT> TypeId<UT> for StorageHandle