pub struct AuthClient { /* private fields */ }Expand description
Provider-neutral check-lock-check authentication and persistent token lifecycle.
Implementations
Sourceimpl AuthClient
impl AuthClient
Sourcepub fn new(
key: String,
flow: Arc<dyn TokenProvider>,
store: Arc<dyn CredentialStore>,
options: AuthOptions,
) -> Self
pub fn new( key: String, flow: Arc<dyn TokenProvider>, store: Arc<dyn CredentialStore>, options: AuthOptions, ) -> Self
Bind one credential identity to its acquisition provider and store.
Sourcepub fn store_name(&self) -> &'static str
pub fn store_name(&self) -> &'static str
Return the active store’s backend identifier.
Sourcepub async fn login(&self) -> Result<Token>
pub async fn login(&self) -> Result<Token>
Acquire and persist a new credential under an exclusive refresh lock.
Sourcepub async fn token(&self) -> Result<Token>
pub async fn token(&self) -> Result<Token>
Load or refresh without starting an interactive login for a missing credential.
Sourcepub async fn token_or_login(&self) -> Result<Token>
pub async fn token_or_login(&self) -> Result<Token>
Load or refresh, permitting login when the store has no credential.
Sourcepub async fn force_refresh(&self) -> Result<Token>
pub async fn force_refresh(&self) -> Result<Token>
Renew even before the refresh window, without forcing an interactive login.
Sourcepub async fn refresh_rejected_token(
&self,
stale_access_token: &str,
) -> Result<Token>
pub async fn refresh_rejected_token( &self, stale_access_token: &str, ) -> Result<Token>
Refresh a rejected token unless another process already replaced it.